UDG Creator Adjustable Aluminium Laptop & Controller Stand at Juno Records
Description: UDG is pleased to present its first laptop stand branded under its Creator series of DJ accessories. UDG s Laptop / controller stand aluminum is the DJ s computer elevation station. Every performer who uses a computer including DJ s, producers and other musicians can appreciate this high quality piece of equipment. It s the only laptop stand for DJ s that balances solid, secure construction, portable, foldaway, height and angle adjustable, 360 degrees rotatable, low weight design and excellent affordability. UDG s stand is fast to assemble.. . Solid and easy to assemble laptop/controller stand for DJs/Producers. High quality aircraft grade anodized aluminum. Height adjustable . Angle adjustable . 360 degree rotatable. Removable sub tray. Fit s 13&quot; 18&quot; laptop, iPad or controller. Airflow constructed tray prevents equipment from overheating. Protective neoprene sleeve included. . Folded. only 4.5 cm / 1.8 inch thick when folded. 47 (H) x 34 (W) x 28 (D) cm . 18.5 (H) x 13.4 (W) [cell cut: 1125 characters, first 1000 kept]
Keywords: UDG, UDG Creator Adjustable Aluminium Laptop & Controller Stand, UDG, laptop stand

Skip Navigation

Secure shopping

MP3, WAV, FLAC

Juno Download offers over 3 million dance tracks in MP3, WAV & FLAC formats, featuring genre pages, advanced audioplayer, super-fast download speeds.

Visit Juno Download

Secure shopping

Studio equipment

Our full range of studio equipment from all the leading equipment and software brands. Guaranteed fast delivery and low prices.

Visit Juno Studio

Secure shopping

DJ equipment

Our full range of DJ equipment from all the leading equipment and software brands. Guaranteed fast delivery and low prices. Visit Juno DJ

Online magazine

Features the latest dance music news, interviews, music and tech reviews, podcasts & more...

Visit Juno Plus

In:

# UDG Creator Adjustable Aluminium Laptop & Controller Stand

## £87.50

SAME DAY SHIPPING!
ParcelForce, FedEx, Royal Mail
Secure shopping
Add to Cart
5 in stock
Add to Wishlist
Order by phone
+44 20 7424 1960
quote 492398
Lines open in 10 hrs 15 mins.
Get low cost finance on any order over £280
More info
Get low-cost finance when you order £280 or more. Add products totalling £280 or more to your cart, then select "Apply for Pay4Later finance" at checkout.
See our Finance page for more information.
Details
Features
Manual/brochure
Delivery
Returns

UDG is pleased to present its first laptop stand branded under its Creator series of DJ accessories. UDG's Laptop / controller stand aluminum is the DJ's computer elevation station. Every performer who uses a computer including DJ's, producers and other musicians can appreciate this high quality piece of equipment. It's the only laptop stand for DJ's that balances solid, secure construction, portable, foldaway, height and angle adjustable, 360 degrees rotatable, low weight design and excellent affordability. UDG's stand is fast to assemble.
Solid and easy-to-assemble laptop/controller stand for DJs/Producers
High quality aircraft grade anodized aluminum
Height adjustable
Angle adjustable
360-degree rotatable
Removable sub tray
Fit 's 13"-18" laptop, iPad or controller
Airflow constructed tray prevents equipment from overheating
Protective neoprene sleeve included
Folded
only 4.5 cm / 1.8 inch thick when folded
47 (H) x 34 (W) x 28 (D) cm
18.5 (H) x 13.4 (W) x 11 (D) inches
Weight
1.6 kg / 3.5 lbs
Stand fully extended

- Solid, lightweight and easy to assemble
- High quality aircraft grade anodized aluminium
- Height and angle adjustable
- 360 degree rotatable
- Removable sub tray
- Fits 13" - 18" laptop, iPad or controller
- Airflow constructed tray
- Protective neoprene sleeve included

If you decide an equipment item is not suitable within 10 days of delivery, you can return it to us for a replacement or refund. Returns must be unused and in their original, undamaged packaging.

Some items are excluded from our money back guarantee, including:
• Computer software that has been unsealed or registered
• Any item that comes directly into contact with the nose, ears or mouth

To arrange a return, please contact our customer service department on 020 7424 2800 or email us at support@juno.co.uk

juno.co.uk Reviews
Best Record Store 2007 / 2008 / 2009
Best Music Outlet 2010, 2012